@@ -12,7 +12,7 @@ import pandas as pd
 from sklearn.base import BaseEstimator
 from sklearn.model_selection import BaseCrossValidator
 from sklearn.pipeline import Pipeline
-from tqdm.notebook import tqdm
+from tqdm.auto import tqdm
 
 from biopsykit.classification.utils import _PipelineWrapper
 from biopsykit.classification.model_selection import nested_cv_grid_search
@@ -171,7 +171,7 @@ class SklearnPipelinePermuter:
 
         Returns
         -------
-        :class:`~biopsykit.classification.model_selection.sklearn_pipeline_permuter.SklearnPipelinePermuter`
+        :class:`~biopsykit.classification.model_selection.SklearnPipelinePermuter`
             ``SklearnPipelinePermuter`` instance with results from csv file
 
         """
@@ -193,7 +193,7 @@ class SklearnPipelinePermuter:
     ):
         """Run fit for all pipeline combinations and sets of parameters.
 
-        This function calls :func:`~biopsykit.classification.model_selection.nested_cv.nested_cv_grid_search` for all
+        This function calls :func:`~biopsykit.classification.model_selection.nested_cv_grid_search` for all
         Pipeline combinations and stores the results in the ``grid_searches`` attribute.
 
         Parameters
@@ -210,7 +210,7 @@ class SklearnPipelinePermuter:
             A str specifying the scoring metric to use for evaluation.
         **kwargs :
             additional arguments that are passed to
-            :func:`~biopsykit.classification.model_selection.nested_cv.nested_cv_grid_search` and
+            :func:`~biopsykit.classification.model_selection.nested_cv_grid_search` and
             :class:`~sklearn.model_selection.GridSearchCV`
 
         """
@@ -381,8 +381,12 @@ class SklearnPipelinePermuter:
         for param_key in self.grid_searches:
             param_dict = {"pipeline_{}".format(key): val for key, val in param_key}
             conf_matrix = np.sum(self.grid_searches[param_key]["conf_matrix"], axis=0)
+            true_labels = np.array(self.grid_searches[param_key]["true_labels"]).ravel()
+            predicted_labels = np.array(self.grid_searches[param_key]["predicted_labels"]).ravel()
             df_metric = pd.DataFrame(param_dict, index=[0])
             df_metric["conf_matrix"] = [list(conf_matrix.flatten())]
+            df_metric["true_labels"] = [true_labels]
+            df_metric["predicted_labels"] = [predicted_labels]
 
             for key in self.grid_searches[param_key]:
                 if "test" in key:
