@@ -14,7 +14,7 @@ import pandas as pd
 from nilspodlib import Dataset, SyncedSession
 
 from biopsykit.utils.time import tz
-from biopsykit.utils._datatype_validation_helper import _assert_file_extension
+from biopsykit.utils._datatype_validation_helper import _assert_file_extension, _assert_is_dtype
 from biopsykit.utils._types import path_t
 
 COUNTER_INCONSISTENCY_HANDLING = Literal["raise", "warn", "ignore"]
@@ -130,7 +130,7 @@ def load_dataset_nilspod(
         datastreams = [datastreams]
 
     # convert dataset to dataframe and localize timestamp
-    df = dataset.data_as_df(datastreams, index="utc_datetime")
+    df = dataset.data_as_df(datastreams, index="local_datetime")
     df.index.name = "time"
     return df, dataset.info.sampling_rate_hz
 
@@ -218,7 +218,7 @@ def load_synced_session_nilspod(
         datastreams = [datastreams]
 
     # convert dataset to dataframe and localize timestamp
-    df = session.data_as_df(datastreams, index="utc_datetime", concat_df=True)
+    df = session.data_as_df(datastreams, index="local_datetime", concat_df=True)
     df.index.name = "time"
     if len(set(session.info.sampling_rate_hz)) > 1:
         raise ValueError(
@@ -242,7 +242,7 @@ def _handle_counter_inconsistencies_dataset(
             warnings.warn(
                 "Counter not monotonously increasing. This might indicate that the dataset is corrupted or "
                 "that the dataset was recorded as part of a synchronized session and might need to be loaded "
-                "using `biopsykit.io.load_synced_session_nilspod()`. "
+                "using `biopsykit.io.nilspod.load_synced_session_nilspod()`. "
                 "Check the counter of the DataFrame manually!"
             )
 
@@ -489,6 +489,7 @@ def get_nilspod_dataset_corrupted_info(dataset: Dataset, file_path: path_t) -> D
         dictionary with corruption information
 
     """
+    _assert_is_dtype(dataset, Dataset)
     nilspod_file_pattern = r"NilsPodX-\w{4}_(.*?).bin"
     # ensure pathlib
     file_path = Path(file_path)
